API Documentation
==================

.. module:: pyrepo

This documentation covers the interfaces exposed by Pyrepo.

Repositories
-------------

.. autoclass:: Repository
    :members:

.. autoclass:: RepoImporter
    :members:
    :private-members:

.. autoexception:: ImportPathError

Commands
---------

.. currentmodule:: pyrepo.commands

.. autoclass:: Command
    :members:

.. autodata:: git
.. autodata:: default_commands

Hosts
------

.. currentmodule:: pyrepo.hosts

.. autoclass:: Host
    :members:

.. autodata:: github
.. autodata:: bitbucket
.. autodata:: default_hosts




